@@ -468,7 +468,7 @@ public class AgentDataEditorView extends AbstractAgentView {
                     long sysupTimeMills =
                         System.currentTimeMillis()
                         - (Long.parseLong(value) * 1000);
-                    ThreadAgent.getInstance().setStartEngineTime(
+                    ThreadAgent.getInstance().setStartSnmpAgentEngineTime(
                         sysupTimeMills);
                 }
             } catch (SnmpBadValueException e) {
